LogsStorage class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readLogsToFile() → Future<String>
Read the Log-String from file
toString() → String
A string representation of this object.
inherited
writeLogsToFile(String log) → Future<File>
Writes the log-String to file

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → LogsStorage
Singleton accessor
no setter